var __read = this && this.__read || function (o, n) {
  var m = typeof Symbol === "function" && o[Symbol.iterator];
  if (!m) return o;
  var i = m.call(o),
    r,
    ar = [],
    e;
  try {
    while ((n === void 0 || n-- > 0) && !(r = i.next()).done) ar.push(r.value);
  } catch (error) {
    e = {
      error: error
    };
  } finally {
    try {
      if (r && !r.done && (m = i["return"])) m.call(i);
    } finally {
      if (e) throw e.error;
    }
  }
  return ar;
};
import { useEffect, useMemo, useRef, useState } from 'react';
/**
 * useValue 受控 & 非受控 value 逻辑封装
 * @param props 组件的props
 * @param defaultValue 默认value
 * @param options.valueName value 在 props 上的名称
 * @param options.fitValue 将外界传入的 value 进行转化
 * @param options.compare 用于对比两个 value 是否相同（返回 true 表示相同）
 * @return [value, setValue, isControlled]
 */
export function useValue(props, defaultValue, options) {
  var _a = options || {},
    _b = _a.valueName,
    valueName = _b === void 0 ? 'value' : _b,
    fitValue = _a.fitValue,
    compare = _a.compare;
  var defaultName = useMemo(function () {
    var n = valueName.substr(0, 1).toUpperCase() + valueName.substr(1);
    return 'default' + n;
  }, [valueName]);
  var isControlled = valueName in props;
  var defaultVal = useMemo(function () {
    var v = defaultValue;
    if (defaultName in props) {
      v = props[defaultName];
    }
    if (isControlled) {
      v = props[valueName];
    }
    if (v === null || typeof v === 'undefined') {
      v = defaultValue;
    }
    if (fitValue) {
      v = fitValue(v);
    }
    return v;
  }, []);
  var lastValue = useRef(defaultValue);
  var getControlledValue = function getControlledValue() {
    var x = props[valueName];
    if (x === null || typeof x === 'undefined') {
      if (fitValue) {
        return fitValue(defaultValue);
      }
      return defaultValue;
    }
    if (fitValue) {
      return fitValue(x);
    }
    return x;
  };
  var _c = __read(useState(defaultVal), 2),
    value = _c[0],
    setValue = _c[1];
  if (valueName in props) {
    // 受控模式
    var newValue = getControlledValue();
    var isSame = compare ? compare(newValue, lastValue.current) : newValue === lastValue.current;
    if (!isSame) {
      lastValue.current = newValue;
      setValue(newValue);
    }
    return [lastValue.current, setValue, isControlled];
  }
  return [value, setValue, isControlled];
}
/**
 * 渲染完成时，显示某个属性不再支持
 * @param comp 组件名称
 * @param props props
 * @param oldName 旧属性
 * @param newName 新属性
 */
export function useDeprecated(comp, props, oldName, newName, defaultValue) {
  useEffect(function () {
    if (oldName in props && console && console.warn) {
      console.warn("Warning: ".concat(comp, ".").concat(oldName, " is deprecated and will be removed in a future version, please use ").concat(newName, " instead"));
    }
  }, []);
  // 旧属性兼容
  if (newName in props) {
    return props[newName];
  }
  if (oldName in props) {
    return props[oldName];
  }
  return defaultValue;
}
var counter = 0;
export function guid(prefix) {
  if (prefix === void 0) {
    prefix = '';
  }
  counter += 1;
  return "".concat(prefix).concat(counter);
}
export function useGuid(prefix) {
  if (prefix === void 0) {
    prefix = '';
  }
  var id = useRef(guid(prefix));
  return id.current;
}