import React, { useCallback } from 'react';
import './style/index';
import { dtMobilePrefix } from '../style/index';
import classnames from 'classnames';
import { withNativeProps } from '../_internal/native-props';
import { mergeProps } from '../_internal/with-default-props';
import Button from '../button';
import Popover from '../popover';
import MoreOutlined from 'dd-icons/lib/MoreOutlined';
import { useMobile } from '../hooks';
export var dtMobileCardPrefix = "".concat(dtMobilePrefix, "-card");
var defaultProps = {
  showDivider: false,
  type: 'column'
};
var Card = /*#__PURE__*/React.memo(function (p) {
  var _a, _b, _c;
  var props = mergeProps(defaultProps, p);
  var className = props.className,
    text = props.text,
    title = props.title,
    topOperate = props.topOperate,
    showDivider = props.showDivider,
    operations = props.operations,
    imageSrc = props.imageSrc,
    type = props.type,
    leftOperate = props.leftOperate,
    children = props.children;
  var prefixCls = dtMobileCardPrefix;
  var isMobile = useMobile();
  var wrapCls = classnames(prefixCls, className, (_a = {}, _a["".concat(dtMobileCardPrefix, "-image-row")] = type === 'row', _a["".concat(dtMobileCardPrefix, "-desktop")] = !isMobile, _a));
  var onClickOperation = useCallback(function (func) {
    if (func && typeof func === 'function') {
      func();
    }
  }, []);
  var renderTopImage = useCallback(function () {
    var _a;
    return /*#__PURE__*/React.createElement("div", {
      className: "".concat(dtMobileCardPrefix, "-top-image")
    }, /*#__PURE__*/React.createElement("img", {
      src: imageSrc,
      className: classnames((_a = {}, _a["".concat(dtMobileCardPrefix, "-card-image-no-bottom-radius")] = (title || text || operations) && type === 'column', _a))
    }));
  }, [imageSrc, title, text, operations, type]);
  var renderTitle = useCallback(function () {
    var _a;
    return /*#__PURE__*/React.createElement("div", {
      className: "".concat(dtMobileCardPrefix, "-header")
    }, /*#__PURE__*/React.createElement("div", {
      className: classnames("".concat(dtMobileCardPrefix, "-title"), (_a = {}, _a["".concat(dtMobileCardPrefix, "-title-desktop")] = !isMobile, _a))
    }, title), topOperate ? (/*#__PURE__*/React.createElement("div", {
      className: "".concat(dtMobileCardPrefix, "-icon-container"),
      onClick: function onClick() {
        return onClickOperation(topOperate.onClick);
      }
    }, /*#__PURE__*/React.createElement("div", {
      className: "".concat(dtMobileCardPrefix, "-operations-icon")
    }, topOperate.icon), /*#__PURE__*/React.createElement("div", {
      className: "".concat(dtMobileCardPrefix, "-operations-text")
    }, topOperate.text))) : null, !isMobile && operations && operations instanceof Array ? (/*#__PURE__*/React.createElement(Popover, {
      placement: 'bottomRight',
      arrow: false,
      overlay: /*#__PURE__*/React.createElement("div", {
        className: "".concat(dtMobileCardPrefix, "-desktop-popover")
      }, operations.map(function (operation) {
        return /*#__PURE__*/React.createElement("div", {
          key: operation.key,
          onClick: operation.onClick,
          className: "".concat(dtMobileCardPrefix, "-desktop-popover-item")
        }, /*#__PURE__*/React.createElement("div", {
          className: "".concat(dtMobileCardPrefix, "-desktop-popover-item-icon")
        }, operation.icon), /*#__PURE__*/React.createElement("div", {
          className: "".concat(dtMobileCardPrefix, "-desktop-popover-item-text")
        }, operation.text));
      }))
    }, /*#__PURE__*/React.createElement(MoreOutlined, {
      className: "".concat(dtMobileCardPrefix, "-operations-container-icon-desktop")
    }))) : null);
  }, [title, topOperate]);
  var renderOperation = useCallback(function () {
    var _a, _b, _c;
    if (type === 'column' && operations && operations instanceof Array && operations.length) {
      return /*#__PURE__*/React.createElement("div", {
        className: "".concat(dtMobileCardPrefix, "-operations-container")
      }, operations.map(function (ele, index) {
        return /*#__PURE__*/React.createElement(React.Fragment, null, /*#__PURE__*/React.createElement("div", {
          onClick: function onClick() {
            return onClickOperation(ele.onClick);
          },
          className: "".concat(dtMobileCardPrefix, "-operations")
        }, /*#__PURE__*/React.createElement("div", {
          className: "".concat(dtMobileCardPrefix, "-operations-icon")
        }, ele.icon), /*#__PURE__*/React.createElement("div", {
          className: "".concat(dtMobileCardPrefix, "-operations-text")
        }, ele.text)), index !== operations.length - 1 ? (/*#__PURE__*/React.createElement("div", {
          className: "".concat(dtMobileCardPrefix, "-operations-divider")
        })) : null);
      }));
    } else if (type === 'column' && operations && !(operations instanceof Array)) {
      var mainOperate_1 = operations.mainOperate,
        subOperate_1 = operations.subOperate,
        operate_1 = operations.operate;
      return /*#__PURE__*/React.createElement("div", {
        className: "".concat(dtMobileCardPrefix, "-fix-operations-container")
      }, operate_1 && (/*#__PURE__*/React.createElement("div", {
        className: classnames("".concat(dtMobileCardPrefix, "-operate"), (_a = {}, _a["".concat(dtMobileCardPrefix, "-operate-text")] = operate_1.text, _a)),
        onClick: function onClick() {
          return onClickOperation(operate_1.onClick);
        }
      }, operate_1.text || operate_1.node)), subOperate_1 && (/*#__PURE__*/React.createElement(Button, {
        size: "middle",
        className: classnames("".concat(dtMobileCardPrefix, "-suboperate"), (_b = {}, _b["".concat(dtMobileCardPrefix, "-suboperate-text")] = subOperate_1.text, _b)),
        onClick: function onClick() {
          return onClickOperation(subOperate_1.onClick);
        }
      }, subOperate_1.text || subOperate_1.node)), mainOperate_1 && (/*#__PURE__*/React.createElement(Button, {
        size: "middle",
        type: "primary",
        className: classnames("".concat(dtMobileCardPrefix, "-mainoperate"), (_c = {}, _c["".concat(dtMobileCardPrefix, "-mainoperate-text")] = mainOperate_1.text, _c)),
        onClick: function onClick() {
          return onClickOperation(mainOperate_1.onClick);
        }
      }, mainOperate_1.text || mainOperate_1.node)));
    }
    return null;
  }, [operations, type]);
  return withNativeProps(props, /*#__PURE__*/React.createElement("div", {
    className: wrapCls
  }, imageSrc && imageSrc.length ? renderTopImage() : null, /*#__PURE__*/React.createElement("div", null, title ? renderTitle() : null, text || children ? (/*#__PURE__*/React.createElement("div", {
    className: classnames("".concat(dtMobileCardPrefix, "-desc-container"), (_b = {}, _b["".concat(dtMobileCardPrefix, "-desc-container-has-header")] = title, _b["".concat(dtMobileCardPrefix, "-desc-container-has-divider")] = showDivider && type === 'column', _b))
  }, text || children)) : null, type === 'row' && leftOperate ? (/*#__PURE__*/React.createElement("div", {
    className: classnames("".concat(dtMobileCardPrefix, "-operate"), "".concat(dtMobileCardPrefix, "-left-operate"), (_c = {}, _c["".concat(dtMobileCardPrefix, "-operate-text")] = leftOperate.text, _c)),
    onClick: function onClick() {
      return onClickOperation(leftOperate.onClick);
    }
  }, leftOperate.text)) : null), isMobile && renderOperation()));
});
Card.displayName = 'Card';
export default Card;