import classnames from 'classnames';
import * as React from 'react';
import Button from '../button';
import { dtMobileEmptyPagePrefix } from '../style';
import './style/index';
import { EmptyTypes } from './api/types';
import { withNativeProps } from '../_internal/native-props';
import { useConfig } from '../config-provider';
import { getEmptySvg, prefersDarkMode } from './utils';
import { ReactSVG } from 'react-svg';
import { useMobile } from '../hooks';
var Empty = function Empty(props) {
  var _a, _b, _c;
  var className = props.className,
    _d = props.type,
    type = _d === void 0 ? EmptyTypes.NOCONTENT : _d,
    title = props.title,
    action = props.action,
    desc = props.desc,
    img = props.img,
    inline = props.inline,
    subAction = props.subAction,
    _e = props.direction,
    direction = _e === void 0 ? 'column' : _e;
  var isMobile = useMobile();
  var locale = useConfig().locale;
  var imgSrc = React.useMemo(function () {
    return getEmptySvg(type, prefersDarkMode(), direction === 'column', img);
  }, [type, img]);
  var renderImg = React.useCallback(function () {
    var _a;
    if (imgSrc && /\.(svg)(\?.*)?$/.test(imgSrc)) {
      return /*#__PURE__*/React.createElement(ReactSVG, {
        src: imgSrc,
        className: "".concat(dtMobileEmptyPagePrefix, "-img")
      });
    } else if (imgSrc) {
      return /*#__PURE__*/React.createElement("div", {
        className: "".concat(dtMobileEmptyPagePrefix, "-top")
      }, /*#__PURE__*/React.createElement("img", {
        className: classnames("".concat(dtMobileEmptyPagePrefix, "-img"), (_a = {}, _a["".concat(dtMobileEmptyPagePrefix, "-img-pc")] = !isMobile, _a)),
        src: imgSrc
      }));
    }
  }, [imgSrc]);
  var renderAction = React.useCallback(function (action, defaultText, isSub) {
    var _a;
    return (action || defaultText) && ((action === null || action === void 0 ? void 0 : action.node) ? (/*#__PURE__*/React.createElement("div", {
      onClick: action.onClick
    }, action.node)) : (/*#__PURE__*/React.createElement(Button, {
      type: (action === null || action === void 0 ? void 0 : action.type) || isSub ? 'secondary' : 'primary',
      size: "middle",
      inline: true,
      onClick: action === null || action === void 0 ? void 0 : action.onClick,
      className: classnames("".concat(dtMobileEmptyPagePrefix, "-button"), (_a = {}, _a["".concat(dtMobileEmptyPagePrefix, "-sub-button")] = isSub, _a))
    }, (action === null || action === void 0 ? void 0 : action.text) || defaultText)));
  }, []);
  var isNotShow = React.useCallback(function (content) {
    if (content !== undefined && !content.trim()) {
      return true;
    }
    return false;
  }, []);
  var config = React.useMemo(function () {
    var _a, _b, _c, _d, _e, _f, _g;
    // @ts-ignore
    var emptyLocale = (_a = locale.Empty) === null || _a === void 0 ? void 0 : _a[type];
    return {
      title: (_b = title !== null && title !== void 0 ? title : emptyLocale === null || emptyLocale === void 0 ? void 0 : emptyLocale.title) !== null && _b !== void 0 ? _b : '',
      desc: (_c = desc !== null && desc !== void 0 ? desc : emptyLocale === null || emptyLocale === void 0 ? void 0 : emptyLocale.describe) !== null && _c !== void 0 ? _c : '',
      btnName: (_e = (_d = action === null || action === void 0 ? void 0 : action.text) !== null && _d !== void 0 ? _d : emptyLocale === null || emptyLocale === void 0 ? void 0 : emptyLocale.btnName) !== null && _e !== void 0 ? _e : '',
      subBtnName: (_g = (_f = subAction === null || subAction === void 0 ? void 0 : subAction.text) !== null && _f !== void 0 ? _f : emptyLocale === null || emptyLocale === void 0 ? void 0 : emptyLocale.subBtnName) !== null && _g !== void 0 ? _g : ''
    };
  }, [type, locale, title, desc, subAction, action]);
  return withNativeProps(props, /*#__PURE__*/React.createElement("div", {
    className: classnames(dtMobileEmptyPagePrefix, className, (_a = {}, _a["".concat(dtMobileEmptyPagePrefix, "-inline")] = inline, _a["".concat(dtMobileEmptyPagePrefix, "-desktop")] = !isMobile, _a))
  }, /*#__PURE__*/React.createElement("div", {
    className: classnames("".concat(dtMobileEmptyPagePrefix, "-content"), (_b = {}, _b["".concat(dtMobileEmptyPagePrefix, "-content-row")] = direction === 'row', _b))
  }, renderImg(), /*#__PURE__*/React.createElement("div", {
    className: "".concat(dtMobileEmptyPagePrefix, "-description")
  }, !isNotShow(config.title) && (/*#__PURE__*/React.createElement("h3", {
    className: "".concat(dtMobileEmptyPagePrefix, "-title")
  }, config.title)), !isNotShow(config.desc) && (/*#__PURE__*/React.createElement("p", {
    className: "".concat(dtMobileEmptyPagePrefix, "-descibe")
  }, config.desc)), /*#__PURE__*/React.createElement("div", {
    className: classnames("".concat(dtMobileEmptyPagePrefix, "-btn-container"), (_c = {}, _c["".concat(dtMobileEmptyPagePrefix, "-btn-container-row")] = direction === 'row', _c))
  }, renderAction(subAction, config.subBtnName, true), renderAction(action, config.btnName, false))))));
};
Empty.displayName = 'Empty';
export default Empty;
export { EmptyTypes };