import _typeof from "@babel/runtime/helpers/esm/typeof";
import * as React from 'react';
/**
 * Since react ref may Function-based or Ref-based
 *
 * Provide this hook to get Ref-based and Function-based in custom component
 *
 *
 * Usage:
 *
 *   function View(props) {
 *     const { hostRef, ref } = useSharedRef(props.forwardedRef)
 *
 *     const onClick = useCallback(() => {
 *        hostRef.current?.focus()
 *     })
 *
 *     return <div ref={ref} />;
 *   }
 *
 *   const App = React.forwardRef((props, ref) => (
 *     <View {...props} forwardedRef={ref} />
 *   ));
 */
export default function useSharedRef(forwardedRef,
// ref callback
onRef) {
  var hostRef = React.useRef();
  function updater(ref) {
    onRef === null || onRef === void 0 ? void 0 : onRef(ref);
    // @ts-ignore
    hostRef.current = ref;
    if (typeof forwardedRef === 'function') {
      forwardedRef(ref);
    } else if (_typeof(forwardedRef) === 'object' && forwardedRef != null) {
      // @ts-ignore
      forwardedRef.current = ref;
    }
  }
  return {
    // Ref-based
    hostRef: hostRef,
    // Function-based
    ref: updater
  };
}