var __read = this && this.__read || function (o, n) {
  var m = typeof Symbol === "function" && o[Symbol.iterator];
  if (!m) return o;
  var i = m.call(o),
    r,
    ar = [],
    e;
  try {
    while ((n === void 0 || n-- > 0) && !(r = i.next()).done) ar.push(r.value);
  } catch (error) {
    e = {
      error: error
    };
  } finally {
    try {
      if (r && !r.done && (m = i["return"])) m.call(i);
    } finally {
      if (e) throw e.error;
    }
  }
  return ar;
};
import React, { forwardRef, useImperativeHandle } from 'react';
import './style/index';
import { dtMobilePrefix } from '../style/index';
import classnames from 'classnames';
import { withNativeProps } from '../_internal/native-props';
import { mergeProps } from '../_internal/with-default-props';
import { convertPx } from '../_internal/convert-px';
import { IndexBarContext } from './context';
import { Sidebar } from './siderbar';
import { Panel } from './Panel';
import { useThrottleFn } from 'ahooks';
import { attachPropertiesToComponent } from '../_internal/attach-properties-to-component';
export var dtMobileIndexBarPrefix = "".concat(dtMobilePrefix, "-indexBar");
var defaultProps = {
  sticky: true
};
// 使用forwardRef将ref传入内部组件
var IndexBar = /*#__PURE__*/forwardRef(function (p, ref) {
  var _a;
  var _b = __read(React.useState([]), 2),
    indexes = _b[0],
    setIndexes = _b[1]; // 序号
  var _c = __read(React.useState(indexes[0]), 2),
    activeIndex = _c[0],
    setActiveIndex = _c[1]; // 激活的序号
  var props = mergeProps(defaultProps, p);
  var titleHeight = convertPx(35);
  var bodyRef = React.useRef(null);
  // 定义暴露给IndexBar使用方的实例值，使用方可以用传入IndexBar的ref调用scroolTo函数
  useImperativeHandle(ref, function () {
    return {
      scrollTo: scrollTo
    };
  });
  React.useEffect(function () {
    var body = bodyRef.current;
    if (!body) return;
    var children = body.children;
    for (var i = 0; i < children.length; i++) {
      var panel = children.item(i);
      if (!panel) continue;
      var panelIndex = panel.dataset['index'];
      // 得到panel的标题元素
      var titleEle = panel.childNodes[0];
      if (panelIndex === activeIndex) {
        // 标题激活
        titleEle.classList.add("".concat(dtMobileIndexBarPrefix, "-anchor-title-active"));
      } else {
        titleEle.classList.remove("".concat(dtMobileIndexBarPrefix, "-anchor-title-active"));
      }
    }
  }, [activeIndex]);
  /**
   * 滑动函数, 使用方可以使用该函数进行旋转
   * @param index
   * @returns
   */
  function scrollTo(index) {
    var body = bodyRef.current;
    if (!body) return;
    var children = body.children;
    for (var i = 0; i < children.length; i++) {
      var panel = children.item(i);
      if (!panel) continue;
      var panelIndex = panel.dataset['index'];
      if (panelIndex === index) {
        body.scrollTop = panel.offsetTop;
        setActiveIndex(index);
        return;
      }
    }
  }
  /**
   * 防抖函数，
   */
  var checkActiveIndex = useThrottleFn(function () {
    var body = bodyRef.current;
    if (!body) return;
    var scrollTop = body.scrollTop;
    var children = body.getElementsByClassName("".concat(dtMobileIndexBarPrefix, "-anchor"));
    for (var i = 0; i < children.length; i++) {
      var panel = children.item(i);
      if (!panel) continue;
      var panelIndex = panel.dataset['index'];
      if (!panelIndex) continue;
      if (panel.offsetTop + panel.clientHeight - titleHeight > scrollTop) {
        setActiveIndex(panelIndex);
        return;
      }
    }
  }, {
    wait: 50,
    trailing: true,
    leading: true
  }).run;
  React.useEffect(function () {
    if (!indexes.length) return;
    checkActiveIndex();
  }, [indexes]);
  var className = props.className;
  var prefixCls = dtMobileIndexBarPrefix;
  var wrapCls = classnames(prefixCls, className, (_a = {}, _a["".concat(dtMobileIndexBarPrefix, "-sticky")] = props.sticky, _a));
  var element = withNativeProps(props, /*#__PURE__*/React.createElement("div", {
    className: wrapCls
  }, /*#__PURE__*/React.createElement(Sidebar, {
    indexes: indexes,
    activeIndex: activeIndex,
    onActive: function onActive(index) {
      scrollTo(index);
    }
  }), /*#__PURE__*/React.createElement("div", {
    className: "".concat(dtMobileIndexBarPrefix, "-body"),
    ref: bodyRef,
    onScroll: checkActiveIndex
  }, props.children)));
  return /*#__PURE__*/React.createElement(IndexBarContext.Provider, {
    value: {
      indexes: indexes,
      setIndexes: setIndexes
    }
  }, element);
});
IndexBar.displayName = 'IndexBar';
export default attachPropertiesToComponent(IndexBar, {
  Panel: Panel
});