import React from 'react';
import './style/index';
import { dtMobilePrefix } from '../style/index';
import classnames from 'classnames';
import { withNativeProps } from '../_internal/native-props';
import { mergeProps } from '../_internal/with-default-props';
import { ProgressLine } from './ProgressLine';
import { ProgressCircle } from './ProgressCircle';
export var dtProgressBarPrefix = "".concat(dtMobilePrefix, "-progress-bar");
export var ProgressStatus;
(function (ProgressStatus) {
  ProgressStatus["loading"] = "loading";
  ProgressStatus["error"] = "error";
  ProgressStatus["success"] = "success";
})(ProgressStatus || (ProgressStatus = {}));
var defaultProps = {
  percent: 0,
  type: 'line',
  status: 'loading',
  circleSize: 'normal'
};
var ProgressBar = /*#__PURE__*/React.memo(function (p) {
  var props = mergeProps(defaultProps, p);
  var className = props.className,
    percent = props.percent,
    type = props.type,
    status = props.status,
    circleSize = props.circleSize;
  var wrapCls = classnames(dtProgressBarPrefix, className);
  var newStatus = ProgressStatus.loading;
  if (percent && percent >= 100) {
    newStatus = ProgressStatus.success;
  } else if (status === 'error') {
    newStatus = ProgressStatus.error;
  }
  var limitPercent = React.useMemo(function () {
    if (percent) {
      return percent <= 100 ? percent : 100;
    } else {
      return 0;
    }
  }, [percent]);
  return withNativeProps(props, /*#__PURE__*/React.createElement("div", {
    className: wrapCls
  }, type === 'line' ? /*#__PURE__*/React.createElement(ProgressLine, {
    percent: limitPercent,
    status: newStatus
  }) : /*#__PURE__*/React.createElement(ProgressCircle, {
    percent: limitPercent,
    status: newStatus,
    circleSize: circleSize
  })));
});
ProgressBar.displayName = 'ProgressBar';
export default ProgressBar;