import React, { FC, ReactNode } from 'react';
import 'regenerator-runtime/runtime.js';
import './style/index';
export declare enum PullStatusEnum {
    Init = "init",
    Pulling = "pulling",
    CanRelease = "canRelease",
    Refreshing = "refreshing",
    Complete = "Complete"
}
export type PullToRefreshProps = {
    /**
     * @description 下拉刷新执行的异步函数，此时status为PullStatusEnum.Refreshing, 异步函数完成之后，status为PullStatusEnum.Complete
     *
     */
    onRefresh?: () => Promise<any>;
    /**
     * @description 下拉时(PullStatusEnum.Pulling)的提示文案
     */
    pullingText?: ReactNode;
    /**
     * @description 可以放手时(PullStatusEnum.CanRelease)的提示文案
     */
    canReleaseText?: ReactNode;
    /**
     * @description 刷新时(PullStatusEnum.Refreshing)的提示文案
     */
    refreshingText?: ReactNode;
    /**
     * @description 完成刷新时(PullStatusEnum.Complete)的提示文案
     */
    completeText?: ReactNode;
    /**
     * @description 完成后延迟消失的时间，单位为 ms
     */
    completeDelay?: number;
    /**
     * @description 头部提示内容区的高度，单位为 px
     */
    headHeight?: number;
    /**
     * @description  禁止下拉刷新
     */
    disabled?: (() => boolean) | boolean;
    /**
     * 根据状态自定义提示区的渲染内容
     * @param status 下拉刷新状态
     * @returns
     */
    renderText?: (status: PullStatusEnum) => ReactNode;
    /**
     * @description 监听状态变化的事件
     * @returns
     */
    onStatusChange?: (status: PullStatusEnum) => void;
};
export declare const defaultProps: {
    completeDelay: number;
    disabled: boolean;
    onRefresh: () => void;
};
declare const PullToRefresh: FC<React.PropsWithChildren<PullToRefreshProps>>;
export default PullToRefresh;
