import React from 'react';
import { BasePropsType } from '../_internal';
import './style/index';
export interface ISearchBarProps extends BasePropsType {
    /**
     * @description 搜索框的默认值
     * @default ""
     */
    defaultValue?: string;
    /**
     * @description 搜索框的当前值
     * @default ""
     */
    value?: string;
    /**
     * @description placeholder
     * @default ""
     */
    placeholder?: string;
    /**
     * @description 是否禁用状态
     * @default false
     */
    disabled?: boolean;
    /**
     * @description 最多允许输入的字符个数
     * @default 140  // TODO 小程序设置了 140
     */
    maxLength?: number;
    /**
     * @description 定制`取消`按钮的文字
     * @default "取消"
     */
    cancelText?: React.ReactNode | string;
    /**
     * @description focus 事件的回调
     * @default -
     */
    onFocus?: (val: string) => void;
    /**
     * @description 当搜索框失去焦点时触发
     * @default -
     */
    onBlur?: (val: string) => void;
    /**
     * @description 点击`取消`按钮触发 (不再自动清除输入框的文字)
     * @default -
     */
    onCancel?: (val: string) => void;
    /**
     * @description 点击 clear 图标触发
     * @default -
     */
    onClear?: (val: string) => void;
    /**
     * @description submit 事件 (点击键盘的 enter)
     * @default -
     */
    onSubmit?: (val: string) => void;
    /**
     * @description 内容发生变更触发 // TODO 截流？ 小程序做了 300ms内只会被触发一次
     * @default -
     */
    onChange?: (value: string) => void;
    /**
     * @param event
     * @returns
     */
    onCompositionStart?: (event: React.CompositionEvent<HTMLInputElement>) => void;
    onCompositionEnd?: (event: React.CompositionEvent<HTMLInputElement>) => void;
    ref?: React.Ref<{
        focus?: () => void;
        blur?: () => void;
    }>;
}
declare const SearchBar: React.FC<ISearchBarProps>;
export default SearchBar;
