import React, { ReactNode } from 'react';
import type { PropagationEvent } from '../_internal/with-stop-propagation';
import type { NativeProps } from '../_internal/native-props';
export type Action = {
    /**
     * @description 操作项内容
     */
    text: string;
    /**
     * @description 操作项点击事件
     */
    onPress?: (e: React.MouseEvent) => void;
    /**
     * @description 操作项类型
     */
    type?: 'primary' | 'danger' | 'success';
    /**
     * @description 操作项样式
     */
    style?: Record<string, any>;
    /**
     * @description 操作的索引（Version > 2.5.0）
     * @default index'
     */
    key?: string | number;
    /**
     * @description 操作的颜色（Version > 2.5.0）
     */
    color?: string;
    /**
     * @description 操作项类名
     */
    className?: string;
};
export type SwipeActionProps = {
    /**
     * @description 点击操作按钮后，是否自动关闭操作区
     * @default true
     */
    autoClose?: boolean;
    /**
     * @description 操作区完全出现时触发的回调函数(side参数支持版本 > 2.5.0)
     * @returns
     */
    onOpen?: (side: 'left' | 'right') => void;
    /**
     * @description 操作区关闭的回调函数
     */
    onClose?: () => void;
    /**
     * @description 禁止操作
     * @default false
     */
    disabled?: boolean;
    /**
     * @description 右侧操作
     */
    right?: Action[];
    /**
     * @description 左侧操作
     */
    left?: Action[];
    /**
   * @description 自定义右侧按钮图标的展示,用于桌面端
   */
    renderIcon?: (more?: React.ReactNode) => React.ReactNode;
    /**
     * @description 桌面端三点式按钮默认是否展示
     * @default true
     */
    defaultMenuVisible?: boolean;
    /**
     * @description 所有操作按钮触发时的回调函数（Version > 2.5.0）
     */
    onAction?: (action: Action, e: React.MouseEvent) => void;
    /**
     * @description 是否滑动其他区域时自动归位（Version > 2.5.0）
     */
    closeOnTouchOutside?: boolean;
    children: ReactNode;
    /**
     * @description 阻止某些事件的冒泡
     * @default []
     */
    stopPropagation?: PropagationEvent[];
} & NativeProps<'--background'>;
