import React from 'react';
import { BasePropsType } from '../_internal';
import './style/index';
import { NativeProps } from '../_internal/native-props';
import { IPageIndicatorProps } from '../page-indicator/index';
import 'regenerator-runtime/runtime.js';
export declare const dtSwiperPrefix: string;
interface AnimationConfig {
    mass?: number;
    tension?: number;
    friction?: number;
    duration?: number;
}
export type IH5SwiperProps = {
    /**
     * @description 走马灯banner的初始位置
     * @default 0
     */
    defaultIndex?: number;
    /**
     * @description 是否允许手势滑动
     * @default false
     */
    allowTouchMove?: boolean;
    /**
     * @description 是否自动播放
     * @default false
     */
    autoplay?: boolean;
    /**
     * @description 自动播放时间间隔
     * @default 3000
     */
    autoplayInterval?: number;
    /**
     * @description 是否循环播放
     * @default false
     */
    loop?: boolean;
    /**
     * @description 切换banner时触发
     * @param index
     * @returns
     */
    onIndexChange?: (index: number) => void;
    /**
     * @description banner页码器的属性
     */
    indicatorProps?: Pick<IPageIndicatorProps, 'color' | 'style' | 'className'>;
    /**
     * @description 自定义指示器
     * @param total
     * @param current
     * @returns
     */
    indicator?: (total: number, current: number) => React.ReactNode;
    /**
     * @description banner的宽度百分比
     * @default 100
     */
    bannerSize?: number;
    /**
     * @description banner的偏移量百分比,（100-bannerSize）/ 2
     * @default 0
     */
    trackOffset?: number;
    /**
     * @description 是否在边界两边卡住，避免发生空白，尽在非loop、且bannerSize < 100 时生效
     * @default false
     */
    stuckAtBoundary?: boolean;
    /**
     * @description 是否在拖动超出内容区域时启用橡皮筋效果，仅在非 loop 模式下生效
     * @default true
     */
    rubberband?: boolean;
    /**
     * @description 未激活banner的缩放尺寸
     * @default 1.0
     */
    noActiveScale?: number;
    /**
     * @description 缩放动画配置
     * @default { mass: 5,tension: 850,friction: 70,duration: 300 }
     */
    scaleAnimationConfig?: AnimationConfig;
    children?: React.ReactElement | React.ReactElement[];
} & BasePropsType & NativeProps<'--border-radius'>;
export type SwiperRef = {
    swipeTo: (index: number) => void;
    swipeNext: () => void;
    swipePrev: () => void;
};
declare const _default: React.ForwardRefExoticComponent<{
    /**
     * @description 走马灯banner的初始位置
     * @default 0
     */
    defaultIndex?: number | undefined;
    /**
     * @description 是否允许手势滑动
     * @default false
     */
    allowTouchMove?: boolean | undefined;
    /**
     * @description 是否自动播放
     * @default false
     */
    autoplay?: boolean | undefined;
    /**
     * @description 自动播放时间间隔
     * @default 3000
     */
    autoplayInterval?: number | undefined;
    /**
     * @description 是否循环播放
     * @default false
     */
    loop?: boolean | undefined;
    /**
     * @description 切换banner时触发
     * @param index
     * @returns
     */
    onIndexChange?: ((index: number) => void) | undefined;
    /**
     * @description banner页码器的属性
     */
    indicatorProps?: Pick<IPageIndicatorProps, "className" | "style" | "color"> | undefined;
    /**
     * @description 自定义指示器
     * @param total
     * @param current
     * @returns
     */
    indicator?: ((total: number, current: number) => React.ReactNode) | undefined;
    /**
     * @description banner的宽度百分比
     * @default 100
     */
    bannerSize?: number | undefined;
    /**
     * @description banner的偏移量百分比,（100-bannerSize）/ 2
     * @default 0
     */
    trackOffset?: number | undefined;
    /**
     * @description 是否在边界两边卡住，避免发生空白，尽在非loop、且bannerSize < 100 时生效
     * @default false
     */
    stuckAtBoundary?: boolean | undefined;
    /**
     * @description 是否在拖动超出内容区域时启用橡皮筋效果，仅在非 loop 模式下生效
     * @default true
     */
    rubberband?: boolean | undefined;
    /**
     * @description 未激活banner的缩放尺寸
     * @default 1.0
     */
    noActiveScale?: number | undefined;
    /**
     * @description 缩放动画配置
     * @default { mass: 5,tension: 850,friction: 70,duration: 300 }
     */
    scaleAnimationConfig?: AnimationConfig | undefined;
    children?: React.ReactElement<any, string | React.JSXElementConstructor<any>> | React.ReactElement<any, string | React.JSXElementConstructor<any>>[] | undefined;
} & BasePropsType & NativeProps<"--border-radius"> & React.RefAttributes<SwiperRef>> & {
    Item: React.FC<React.PropsWithChildren<{
        onClick?: ((e: React.MouseEvent<HTMLDivElement, MouseEvent>) => void) | undefined;
    } & NativeProps<never>>>;
};
export default _default;
