var __assign = this && this.__assign || function () {
  __assign = Object.assign || function (t) {
    for (var s, i = 1, n = arguments.length; i < n; i++) {
      s = arguments[i];
      for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p)) t[p] = s[p];
    }
    return t;
  };
  return __assign.apply(this, arguments);
};
var __read = this && this.__read || function (o, n) {
  var m = typeof Symbol === "function" && o[Symbol.iterator];
  if (!m) return o;
  var i = m.call(o),
    r,
    ar = [],
    e;
  try {
    while ((n === void 0 || n-- > 0) && !(r = i.next()).done) ar.push(r.value);
  } catch (error) {
    e = {
      error: error
    };
  } finally {
    try {
      if (r && !r.done && (m = i["return"])) m.call(i);
    } finally {
      if (e) throw e.error;
    }
  }
  return ar;
};
import React, { forwardRef } from 'react';
import './style/index';
import { dtMobilePrefix } from '../style/index';
import classnames from 'classnames';
import { withNativeProps } from '../_internal/native-props';
import { staged } from 'staged-components';
import { mergeProps } from '../_internal/with-default-props';
import { SwiperItem } from './SwiperItem';
import { useRefState } from '../_internal/use-ref-state';
import { bound } from '../_internal/bound';
import PageIndicator from '../page-indicator/index';
import { attachPropertiesToComponent } from '../_internal/attach-properties-to-component';
import { useSpring, animated } from 'dd-react-spring-web';
import { useDrag } from 'dd-use-gesture-react';
import 'regenerator-runtime/runtime.js';
import classNames from 'classnames';
export var dtSwiperPrefix = "".concat(dtMobilePrefix, "-swiper");
var SwiperItemSpace = 4; // swiper的bannnerSeize小于100%时，item之间的间距
var defaultProps = {
  defaultIndex: 0,
  allowTouchMove: true,
  autoplay: false,
  autoplayInterval: 3000,
  loop: true,
  bannerSize: 100,
  trackOffset: 0,
  stuckAtBoundary: false,
  rubberband: true,
  noActiveScale: 1.0,
  scaleAnimationConfig: {
    mass: 5,
    tension: 850,
    friction: 70,
    duration: 300
  }
};
/**
 * 让value整除division，得到index永远在0~division之间，且会达到循环的效果
 * @param value
 * @param division
 * @returns
 */
function modulus(value, division) {
  var remainder = value % division;
  return remainder < 0 ? remainder + division : remainder;
}
var LoopSwiperContainer = function LoopSwiperContainer(props) {
  var _a;
  var bannerSize = props.bannerSize,
    noActiveScale = props.noActiveScale,
    current = props.current,
    validChildrenLen = props.validChildrenLen,
    index = props.index,
    position = props.position,
    count = props.count,
    children = props.children;
  var rate = React.useMemo(function () {
    var result = bannerSize * (1 - noActiveScale) / 2;
    if (current === validChildrenLen - 1 && index === 0) {
      return result;
    } else if (index === validChildrenLen - 1 && current === 0 || index < current) {
      return result * -1;
    } else if (index === current) {
      return 0;
    }
    return result;
  }, [bannerSize, noActiveScale, validChildrenLen, index, current]);
  var _b = __read(useSpring(function () {
      return {
        scale: index === current ? 1.0 : props.noActiveScale,
        config: props.animationConfig
      };
    }), 2),
    styles = _b[0],
    set = _b[1];
  var getStyle = React.useCallback(function (index, rate, current) {
    if (index !== current) {
      set({
        scale: props.noActiveScale
      });
    } else {
      set({
        scale: 1.0
      });
    }
    return __assign(__assign({}, styles), {
      x: position.to(function (position) {
        var finalPosition = -position + index * 100;
        var totalWidth = count * 100;
        var flagWidth = totalWidth / 2;
        finalPosition = modulus(finalPosition + flagWidth, totalWidth) - flagWidth;
        return "".concat(finalPosition, "%");
      }),
      left: "".concat(-(index * 100 + rate), "%")
    });
  }, [props.noActiveScale, props.animationConfig]);
  return /*#__PURE__*/React.createElement(animated.div, {
    className: classNames("".concat(dtSwiperPrefix, "-slide"), (_a = {}, _a["".concat(dtSwiperPrefix, "-slide-active")] = index === current, _a)),
    style: getStyle(index, rate, current)
  }, children);
};
// staged的作用
var Swiper = /*#__PURE__*/forwardRef(staged(function (p, ref) {
  var _a;
  var props = mergeProps(defaultProps, p);
  var _b = __read(React.useState(props.defaultIndex), 2),
    current = _b[0],
    setCurrent = _b[1];
  var _c = __read(useRefState(false), 3),
    dragging = _c[0],
    setDragging = _c[1],
    draggingRef = _c[2];
  var className = props.className;
  var prefixCls = dtSwiperPrefix;
  // swiper滑块宽度百分比
  var slideRatio = props.bannerSize / 100;
  // swiper滑块偏移百分比
  var offsetRatio = props.trackOffset / 100;
  var _d = React.useMemo(function () {
      var count = 0;
      var validChildren = React.Children.map(props.children, function (child) {
        if (! /*#__PURE__*/React.isValidElement(child)) return null;
        if (child.type !== SwiperItem) {
          console.error('Swiper, the children of "Swiper" must be "Swiper.Item" components');
          return null;
        }
        count++;
        return child;
      });
      return {
        validChildren: validChildren,
        count: count
      };
    }, [props.children]),
    validChildren = _d.validChildren,
    count = _d.count;
  if (count === 0 || !validChildren) {
    console.error('swiper needs at least one child');
  }
  var loop = props.loop;
  // 所有滑块宽度不超过一屏，则不需要循环
  if (slideRatio * (count - 1) < 1) {
    loop = false;
  }
  var trackRef = React.useRef(null);
  function getSlidePixels() {
    var track = trackRef.current;
    if (!track) return 0;
    var trackPixels = track.offsetWidth;
    return trackPixels * props.bannerSize / 100;
  }
  function boundIndex(current) {
    var min = 0;
    var max = count - 1;
    if (props.stuckAtBoundary) {
      min += (1 - slideRatio - offsetRatio) / slideRatio;
      max -= (1 - slideRatio - offsetRatio) / slideRatio;
    }
    return bound(current, min, max);
  }
  var _e = __read(useSpring(function () {
      return {
        position: boundIndex(current) * 100,
        config: {
          tension: 200,
          friction: 30
        },
        onRest: function onRest() {
          if (draggingRef.current) return;
          var rawX = position.get();
          var totalWidth = 100 * count;
          var standardPosition = modulus(rawX, totalWidth);
          if (standardPosition === rawX) return;
          api.start({
            position: standardPosition,
            immediate: true
          });
        }
      };
    }, [count]), 2),
    position = _e[0].position,
    api = _e[1];
  // 处理手势滑动事件
  var bind = useDrag(function (state) {
    var slidePixels = getSlidePixels();
    if (!slidePixels) return;
    var paramIndex = 0;
    var offset = state.offset[paramIndex];
    var direction = state.direction[paramIndex];
    var velocity = state.velocity[paramIndex];
    setDragging(true);
    if (!state.last) {
      api.start({
        position: offset * 100 / slidePixels,
        immediate: true
      });
    } else {
      var minIndex = Math.floor(offset / slidePixels);
      var maxIndex = minIndex + 1;
      var index = Math.round((offset + velocity * 2000 * direction) / slidePixels);
      swipeTo(bound(index, minIndex, maxIndex));
      window.setTimeout(function () {
        setDragging(false);
      });
    }
  }, {
    transform: function transform(_a) {
      var _b = __read(_a, 2),
        x = _b[0],
        y = _b[1];
      return [-x, -y];
    },
    from: function from() {
      var slidePixels = getSlidePixels();
      return [position.get() / 100 * slidePixels, position.get() / 100 * slidePixels];
    },
    bounds: function bounds() {
      if (loop) return {};
      var slidePixels = getSlidePixels();
      var lowerBound = boundIndex(0) * slidePixels;
      var upperBound = boundIndex(count - 1) * slidePixels;
      return {
        left: lowerBound,
        right: upperBound
      };
    },
    rubberband: props.rubberband,
    axis: 'x',
    preventScroll: true,
    pointer: {
      touch: true
    }
  });
  // 处理换页
  function swipeTo(index, immediate) {
    var _a, _b;
    if (immediate === void 0) {
      immediate = false;
    }
    if (loop) {
      var i = modulus(index, count);
      setCurrent(i);
      (_a = props.onIndexChange) === null || _a === void 0 ? void 0 : _a.call(props, i); // 只有当onIndexChange有的时候才会调用
      api.start({
        position: index * 100,
        immediate: immediate
      });
    } else {
      var i = bound(index, 0, count - 1);
      setCurrent(i);
      (_b = props.onIndexChange) === null || _b === void 0 ? void 0 : _b.call(props, i);
      api.start({
        position: boundIndex(i) * 100,
        immediate: immediate
      });
    }
  }
  function swipeNext() {
    swipeTo(Math.round(position.get() / 100) + 1);
  }
  function swipePrev() {
    swipeTo(Math.round(position.get() / 100) - 1);
  }
  // 为传入的ref传入这些方法
  React.useImperativeHandle(ref, function () {
    return {
      swipeTo: swipeTo,
      swipeNext: swipeNext,
      swipePrev: swipePrev
    };
  });
  // 处理自动播放
  var autoplay = props.autoplay,
    autoplayInterval = props.autoplayInterval;
  React.useEffect(function () {
    if (!autoplay || dragging) return;
    var interval = window.setInterval(function () {
      swipeNext();
    }, autoplayInterval);
    return function () {
      window.clearInterval(interval);
    };
  }, [autoplay, autoplayInterval, dragging]);
  var wrapCls = classnames(prefixCls, className);
  // 根据props设置滑块banner的宽度与偏移
  var style = {
    '--banner-size': "".concat(props.bannerSize, "%"),
    '--track-offset': "".concat(props.trackOffset, "%"),
    '--banner-space': "".concat(SwiperItemSpace, "px")
    // '--current-zoom': `${props.currentZoom}`
  };
  function renderTrackInner() {
    if (loop) {
      return /*#__PURE__*/React.createElement("div", {
        className: "".concat(prefixCls, "-track-inner")
      }, React.Children.map(validChildren, function (child, index) {
        return /*#__PURE__*/React.createElement(LoopSwiperContainer, {
          index: index,
          count: count,
          position: position,
          bannerSize: props.bannerSize,
          noActiveScale: props.noActiveScale,
          current: current,
          validChildrenLen: validChildren.length,
          animationConfig: props.scaleAnimationConfig
        }, child);
      }));
    } else {
      return /*#__PURE__*/React.createElement(animated.div, {
        className: "".concat(prefixCls, "-track-inner"),
        style: {
          x: position.to(function (position) {
            return "".concat(-position, "%");
          })
        }
      }, React.Children.map(validChildren, function (child) {
        return /*#__PURE__*/React.createElement("div", {
          className: "".concat(prefixCls, "-slide")
        }, child);
      }));
    }
  }
  return withNativeProps(props, /*#__PURE__*/React.createElement("div", {
    className: wrapCls,
    style: style
  }, /*#__PURE__*/React.createElement("div", __assign({
    ref: trackRef,
    className: classnames("".concat(prefixCls, "-track"), (_a = {}, _a["".concat(prefixCls, "-track-allow-touch-move")] = props.allowTouchMove, _a["".concat(prefixCls, "-padding")] = props.bannerSize < 100, _a)),
    onClickCapture: function onClickCapture(e) {
      if (draggingRef.current) {
        e.stopPropagation();
      }
    }
  }, props.allowTouchMove ? bind() : {}), renderTrackInner()), props.indicator === undefined ? (/*#__PURE__*/React.createElement("div", {
    className: "".concat(prefixCls, "-indicator")
  }, /*#__PURE__*/React.createElement(PageIndicator, __assign({}, props.indicatorProps, {
    total: count,
    current: current,
    onClick: function onClick(idx) {
      return swipeTo(idx);
    }
  })))) : (/*#__PURE__*/React.createElement("div", {
    className: "".concat(prefixCls, "-indicator")
  }, props.indicator(count, current)))));
}));
Swiper.displayName = 'Swiper';
export default attachPropertiesToComponent(Swiper, {
  Item: SwiperItem
});