"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");
Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.defaultMinDate = exports.defaultMaxDate = exports.Mode = exports.DateManager = void 0;
var _react = _interopRequireDefault(require("react"));
var defaultMaxDate = exports.defaultMaxDate = new Date(2030, 1, 1, 23, 59, 59);
var defaultMinDate = exports.defaultMinDate = new Date(2000, 1, 1, 0, 0, 0);
var Mode;
(function (Mode) {
  Mode["DATETIME"] = "datetime";
  Mode["DATE"] = "date";
  Mode["TIME"] = "time";
  Mode["MONTH"] = "month";
  Mode["YEAR"] = "year";
})(Mode || (exports.Mode = Mode = {}));
function cloneDate(date) {
  return new Date(+date);
}
function getDaysInMonth(date) {
  return new Date(date.getFullYear(), date.getMonth() + 1, 0).getDate();
}
// 至今，特殊年份替代
var UNTIL_NOW_YEAR = 10000;
var UNTIL_NOW_TEXT = '至今';
var ONE_DAY = 24 * 60 * 60 * 1000;
var DateManager = exports.DateManager = /** @class */function () {
  function DateManager(props) {
    var _a, _b;
    this.minDate = (_a = props.minDate) !== null && _a !== void 0 ? _a : defaultMinDate;
    this.maxDate = (_b = props.maxDate) !== null && _b !== void 0 ? _b : defaultMaxDate;
  }
  DateManager.prototype.getMinDate = function () {
    return this.minDate || defaultMinDate;
  };
  DateManager.prototype.getMaxDate = function () {
    return this.maxDate || defaultMaxDate;
  };
  DateManager.prototype.getMinYear = function () {
    return this.getMinDate().getFullYear();
  };
  DateManager.prototype.getMaxYear = function () {
    return this.getMaxDate().getFullYear();
  };
  DateManager.prototype.getMinMonth = function () {
    return this.getMinDate().getMonth();
  };
  DateManager.prototype.getMaxMonth = function () {
    return this.getMaxDate().getMonth();
  };
  DateManager.prototype.getMinDay = function () {
    return this.getMinDate().getDate();
  };
  DateManager.prototype.getMaxDay = function () {
    return this.getMaxDate().getDate();
  };
  DateManager.prototype.getMinHour = function () {
    return this.getMinDate().getHours();
  };
  DateManager.prototype.getMaxHour = function () {
    return this.getMaxDate().getHours();
  };
  DateManager.prototype.getMinMinute = function () {
    return this.getMinDate().getMinutes();
  };
  DateManager.prototype.getMaxMinute = function () {
    return this.getMaxDate().getMinutes();
  };
  DateManager.prototype.getDate = function (date, mode) {
    return this.clipDate(date || defaultMinDate, mode);
  };
  DateManager.prototype.clipDate = function (date, mode) {
    var selYear = date.getFullYear();
    var minDate = this.getMinDate();
    var maxDate = this.getMaxDate();
    if (selYear === UNTIL_NOW_YEAR) {
      return date;
    }
    if (mode === Mode.DATETIME) {
      if (date < minDate) {
        return cloneDate(minDate);
      }
      if (date > maxDate) {
        return cloneDate(maxDate);
      }
    } else if (mode === Mode.DATE || mode === Mode.YEAR || mode === Mode.MONTH) {
      // compare-two-dates: https://stackoverflow.com/a/14629978/2190503
      if (Number(+date + ONE_DAY) <= Number(minDate)) {
        return cloneDate(minDate);
      }
      if (Number(date) >= +maxDate + ONE_DAY) {
        return cloneDate(maxDate);
      }
    } else if (mode === Mode.TIME) {
      var maxHour = maxDate.getHours();
      var maxMinutes = maxDate.getMinutes();
      var minHour = minDate.getHours();
      var minMinutes = minDate.getMinutes();
      var hour = date.getHours();
      var minutes = date.getMinutes();
      if (date.getMonth() !== minDate.getMonth() || date.getDate() !== minDate.getDate()) {
        return date;
      }
      if (hour < minHour || hour === minHour && minutes < minMinutes) {
        return cloneDate(minDate);
      }
      if (hour > maxHour || hour === maxHour && minutes > maxMinutes) {
        return cloneDate(maxDate);
      }
    }
    return date;
  };
  DateManager.prototype.renderColLabel = function (value, local, prefixCls) {
    return /*#__PURE__*/_react["default"].createElement("span", {
      className: "".concat(prefixCls, "-col-item-text")
    }, value, /*#__PURE__*/_react["default"].createElement("span", {
      className: "".concat(prefixCls, "-col-item-text-unit")
    }, local));
  };
  DateManager.prototype.getDateData = function (d, mode, showUntilNow, locale, prefixCls, formatMonth, formatDay) {
    var date = this.getDate(d, mode);
    var selYear = date.getFullYear();
    var selMonth = date.getMonth();
    var minDateYear = this.getMinYear();
    var maxDateYear = this.getMaxYear();
    var minDateMonth = this.getMinMonth();
    var maxDateMonth = this.getMaxMonth();
    var minDateDay = this.getMinDay();
    var maxDateDay = this.getMaxDay();
    var years = [];
    for (var i = minDateYear; i <= maxDateYear; i++) {
      years.push({
        value: i + '',
        label: this.renderColLabel(i, locale.year, prefixCls)
      });
    }
    if (showUntilNow) {
      years.push({
        value: UNTIL_NOW_YEAR + '',
        label: UNTIL_NOW_TEXT
      });
    }
    var yearCol = {
      key: 'year',
      props: {
        children: years
      }
    };
    if (mode === Mode.YEAR) {
      return [yearCol];
    }
    var months = [];
    var minMonth = 0;
    var maxMonth = 11;
    if (selYear !== UNTIL_NOW_YEAR) {
      if (minDateYear === selYear) {
        minMonth = minDateMonth;
      }
      if (maxDateYear === selYear) {
        maxMonth = maxDateMonth;
      }
      for (var i = minMonth; i <= maxMonth; i++) {
        var label = formatMonth ? formatMonth(i, date) : this.renderColLabel(i + 1, locale.month, prefixCls);
        months.push({
          value: i + '',
          label: label
        });
      }
    }
    var monthCol = {
      key: 'month',
      props: {
        children: months
      }
    };
    if (mode === Mode.MONTH) {
      return [yearCol, monthCol];
    }
    var days = [];
    if (selYear !== UNTIL_NOW_YEAR) {
      var minDay = 1;
      var maxDay = getDaysInMonth(date);
      if (minDateYear === selYear && minDateMonth === selMonth) {
        minDay = minDateDay;
      }
      if (maxDateYear === selYear && maxDateMonth === selMonth) {
        maxDay = maxDateDay;
      }
      for (var i = minDay; i <= maxDay; i++) {
        var label = formatDay ? formatDay(i, date) : this.renderColLabel(i, locale.day, prefixCls);
        days.push({
          value: i + '',
          label: label
        });
      }
    }
    return [yearCol, monthCol, {
      key: 'day',
      props: {
        children: days
      }
    }];
  };
  DateManager.prototype.getValueCols = function (d, mode, showUntilNow, locale, prefixCls, use12Hours, time, formatMonth, formatDay) {
    var date = this.clipDate(d || defaultMinDate, mode);
    var cols = [];
    var value = [];
    if (mode === Mode.YEAR) {
      return {
        cols: this.getDateData(d, mode, showUntilNow, locale, prefixCls, formatMonth, formatDay),
        value: [date.getFullYear() + '']
      };
    }
    if (mode === Mode.MONTH) {
      return {
        cols: this.getDateData(d, mode, showUntilNow, locale, prefixCls, formatMonth, formatDay),
        value: [date.getFullYear() + '', date.getMonth() + '']
      };
    }
    if (mode === Mode.DATETIME || mode === Mode.DATE) {
      cols = this.getDateData(d, mode, showUntilNow, locale, prefixCls, formatMonth, formatDay);
      value = [date.getFullYear() + '', date.getMonth() + '', date.getDate() + ''];
    }
    if (mode === Mode.DATETIME || mode === Mode.TIME) {
      cols = cols.concat(time === null || time === void 0 ? void 0 : time.cols);
      var hour = date.getHours();
      var dtValue = [hour + '', (time === null || time === void 0 ? void 0 : time.selMinute) + ''];
      var nhour = hour;
      if (use12Hours) {
        nhour = hour > 12 ? hour - 12 : hour;
        dtValue = [nhour + '', (time === null || time === void 0 ? void 0 : time.selMinute) + '', (hour >= 12 ? 1 : 0) + ''];
      }
      value = value.concat(dtValue);
    }
    return {
      value: value,
      cols: cols
    };
  };
  return DateManager;
}();