import React from 'react';
import { Page } from './convert';
import { NativeProps } from '../_internal/native-props';
import './style/index';
export type CalendarRef = {
    jumpTo: (page: Page | ((page: Page) => Page)) => void;
    jumpToToday: () => void;
};
export declare enum ModeType {
    YEAR = "year",
    MONTH = "month",
    DAY = "day"
}
export type CalendarProps = {
    /**
     * @description 每周以周几作为第一天
     * @default 'Sunday'
     */
    weekStartsOn?: 'Monday' | 'Sunday';
    /**
     *
     * @param date
     * @returns
     */
    shouldDisableDate?: (date: Date) => boolean;
    /**
     * @description 可选择范围的最大值
     */
    max?: Date;
    /**
     * @description 可选择范围的最小值
     */
    min?: Date;
    /**
     * @description 可切换到的最早日期
     */
    minPage?: Page;
    /**
     * @description 可切换到的最晚日期
     */
    maxPage?: Page;
    /**
     * @description 隐藏未来的日期
     */
    enableDisabledFuture?: boolean;
    /**
     * @description
     */
    ignorePageChanged?: boolean;
    /**
     * @description 日期标注信息的渲染函数
     * @param date
     * @param isBegin
     * @param isEnd
     * @returns
     */
    renderLabel?: (date: Date, isBegin: boolean, isEnd: boolean) => React.ReactNode;
    /**
     * @description 自定义日期渲染
     * @param date
     * @returns
     */
    renderDate?: (date: Date) => React.ReactNode;
    /**
     * @description 自定义头部渲染（用于年月的切换）
     * @param handleChange
     * @returns
     */
    renderHeader?: (handleChange: (action: 'subtract' | 'add', num: number, type: 'month' | 'year') => void) => React.ReactNode;
    /**
     * @description 自定义底部渲染
     * @returns
     */
    renderFooter?: () => React.ReactNode;
} & ({
    selectionMode?: undefined;
    value?: undefined;
    defaultValue?: undefined;
    onChange?: undefined;
} | {
    selectionMode: 'single';
    value?: Date | null;
    defaultValue?: Date | null;
    onChange?: (val: Date | null) => void;
} | {
    selectionMode: 'range';
    value?: [Date, Date] | null;
    defaultValue?: [Date, Date] | null;
    onChange?: (val: [Date, Date] | null) => void;
}) & NativeProps;
declare const Calendar: React.ForwardRefExoticComponent<CalendarProps & React.RefAttributes<CalendarRef>>;
export default Calendar;
