/// <reference types="react" />
import type { BasePropsType } from '../_internal';
import type { NativeProps } from '../_internal/native-props';
export type OperateType = {
    /**
     * @description operate的key
     * @default '-'
     */
    key?: number | string;
    /**
     * @description operate的icon
     * @default'-'
     */
    icon?: React.ReactElement;
    /**
     * @description operate的文本
     * @default'-'
     */
    text?: string | React.ReactElement;
    /**
     * @description operate点击触发的事件
     * @default'-'
     */
    onClick?: () => void;
};
export type OperateFixedEle = {
    /**
     * @description 固定操作的文字
     * @default'-'
     */
    text?: number;
    /**
     * @description 固定操作可传入的元素
     * @default'-'
     */
    node?: React.ReactElement;
    /**
     * @description 固定操作点击触发的事件
     * @default'-'
     */
    onClick: () => void;
};
export type OperateFixed = {
    /**
     * @description 固定操作中的主操作
     * @default'-'
     */
    mainOperate: OperateFixedEle;
    /**
     * @description 固定操作的次操作
     * @default'-'
     */
    subOperate: OperateFixedEle;
    /**
     * @description 固定操作的操作
     * @default'-'
     */
    operate: OperateFixedEle;
};
export type CardProps = {
    /**
     * @description 文字卡片标题
     * @default '-'
     */
    title?: string | React.ReactNode;
    /**
     * @description 文字卡片中的文字
     * @default '-'
     */
    text?: string;
    /**
     * @description 图片链接
     * @default 'string''
     */
    imageSrc?: string;
    /**
     * @description 图片卡片的布局
     * @default 'column''
     */
    type?: 'row' | 'column';
    /**
     * @description 顶部操作
     * @default ‘-’
     */
    topOperate?: OperateType;
    /**
     * @description 左侧操作，仅在左右结构中出现
     * @default ‘-’
     */
    leftOperate?: OperateFixedEle;
    /**
     * @description 文字卡片是否显示分割线
     * @default false
     */
    showDivider?: boolean;
    /**
     * @description 卡片操作数组
     * @default '-''
     */
    operations?: OperateType[] | OperateFixed;
} & BasePropsType & NativeProps<'--border-radius'>;
