import * as React from 'react';
import { PageContainerAction } from '../page-container';
export interface DrawerProps extends React.HTMLAttributes<HTMLDivElement> {
    /**
     * @description 是否显示
     * @default false
     */
    visible?: boolean;
    /**
     * @description 是否显示遮罩
     * @default true
     */
    mask?: boolean;
    /**
     * @description 点击遮罩是否可关闭
     * @default true
     */
    maskClosable?: boolean;
    /**
     * @description 遮盖背景被点击时调用
     * @default '-'
     */
    onVisibleChange?: (visible: boolean) => void;
    /**
     * @description 关闭前回调，
     * @returns 返回false，则阻止关闭
     */
    beforeClose?: () => Promise<boolean>;
    /**
     * @description 抽屉所在位置
     * @default 'bottom'
     */
    position?: 'top' | 'bottom' | 'left' | 'right';
    /**
     * @description 抽屉尺寸（仅移动端）
     * @default 'auto'
     */
    size?: 'large' | 'middle' | 'auto';
    /**
     * @description 标题
     */
    title?: string;
    /**
     * @description 行动点
     */
    actions?: PageContainerAction[];
    /**
     * @description 桌面轻量级 popver 方式适配，适合内容较简单场景，必须传入 trigger
     * @default false
     **/
    lightweight?: boolean;
    /**
     * @description 用于触发 Drawer 打开的 dom，lightweight 模式必须传入
     */
    trigger?: React.ReactElement;
    /**
     * @description 是否是嵌入式的抽屉
     **/
    embedded?: boolean;
    /**
     * @description 抽屉头部是否展示分割线
     * @default true
     */
    topBordered?: boolean;
    /**
     * @description 指定 Drawer 挂载的 HTML 节点, 不传为挂载在body上
     * @default false
     */
    getContainer?: HTMLElement | (() => HTMLElement) | null;
    /**
     * @description Drawer关闭时调用的事件
     * @returns
     */
    onClose?: () => void;
}
export declare enum EPlacement {
    'top' = "top",
    'bottom' = "bottom",
    'left' = "left",
    'right' = "right"
}
