"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports["default"] = useControlled;
exports.useControlledByChecked = useControlledByChecked;
exports.useControlledByValue = useControlledByValue;
var _react = require("react");
var _internal = require("../_internal");
var __read = void 0 && (void 0).__read || function (o, n) {
  var m = typeof Symbol === "function" && o[Symbol.iterator];
  if (!m) return o;
  var i = m.call(o),
    r,
    ar = [],
    e;
  try {
    while ((n === void 0 || n-- > 0) && !(r = i.next()).done) ar.push(r.value);
  } catch (error) {
    e = {
      error: error
    };
  } finally {
    try {
      if (r && !r.done && (m = i["return"])) m.call(i);
    } finally {
      if (e) throw e.error;
    }
  }
  return ar;
};
// 用于受控和非受控组件
function useControlled(_value, _defaultValue, _onChange) {
  var controlled = _value != null;
  // controlled 的时候, _value 必有值
  var initValue = controlled ? _value : _defaultValue;
  // 必须提供 defaultValue. 否则会导致下层依赖的 input 由非受控模式切换到受控模式
  if (initValue == null) {
    (0, _internal.error)(false, 'chore', 'undefined defaultValue with uncontrolled');
  }
  var _a = __read((0, _react.useState)(initValue), 2),
    value = _a[0],
    setValue = _a[1];
  // 受控模式更新 value
  (0, _react.useEffect)(function () {
    if (controlled) {
      setValue(_value);
    }
  }, [_value, controlled]);
  var onChange = (0, _react.useCallback)(function (v) {
    // 非受控模式更新 value
    if (!controlled) {
      setValue(v);
    }
    _onChange === null || _onChange === void 0 ? void 0 : _onChange(v);
  }, [controlled, _onChange]);
  return {
    value: value,
    onChange: onChange
  };
}
function useControlledByValue(props) {
  return useControlled(props.value, props.defaultValue, props.onChange);
}
function useControlledByChecked(props) {
  var _a = useControlled(props.checked, props.defaultChecked, props.onChange),
    value = _a.value,
    onChange = _a.onChange;
  return {
    checked: value,
    onChange: onChange
  };
}