import * as React from 'react';
/**
 * Since react ref may Function-based or Ref-based
 *
 * Provide this hook to get Ref-based and Function-based in custom component
 *
 *
 * Usage:
 *
 *   function View(props) {
 *     const { hostRef, ref } = useSharedRef(props.forwardedRef)
 *
 *     const onClick = useCallback(() => {
 *        hostRef.current?.focus()
 *     })
 *
 *     return <div ref={ref} />;
 *   }
 *
 *   const App = React.forwardRef((props, ref) => (
 *     <View {...props} forwardedRef={ref} />
 *   ));
 */
export default function useSharedRef<T>(forwardedRef: T, onRef?: (ref: T) => void): {
    hostRef: React.MutableRefObject<T | undefined>;
    ref: (ref: T) => void;
};
