"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");
var _typeof3 = require("@babel/runtime/helpers/typeof");
Object.defineProperty(exports, "__esModule", {
  value: true
});
exports["default"] = useSharedRef;
var _typeof2 = _interopRequireDefault(require("@babel/runtime/helpers/typeof"));
var React = _interopRequireWildcard(require("react"));
function _getRequireWildcardCache(e) { if ("function" != typeof WeakMap) return null; var r = new WeakMap(), t = new WeakMap(); return (_getRequireWildcardCache = function _getRequireWildcardCache(e) { return e ? t : r; })(e); }
function _interopRequireWildcard(e, r) { if (!r && e && e.__esModule) return e; if (null === e || "object" != _typeof3(e) && "function" != typeof e) return { "default": e }; var t = _getRequireWildcardCache(r); if (t && t.has(e)) return t.get(e); var n = { __proto__: null }, a = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var u in e) if ("default" !== u && {}.hasOwnProperty.call(e, u)) { var i = a ? Object.getOwnPropertyDescriptor(e, u) : null; i && (i.get || i.set) ? Object.defineProperty(n, u, i) : n[u] = e[u]; } return n["default"] = e, t && t.set(e, n), n; }
/**
 * Since react ref may Function-based or Ref-based
 *
 * Provide this hook to get Ref-based and Function-based in custom component
 *
 *
 * Usage:
 *
 *   function View(props) {
 *     const { hostRef, ref } = useSharedRef(props.forwardedRef)
 *
 *     const onClick = useCallback(() => {
 *        hostRef.current?.focus()
 *     })
 *
 *     return <div ref={ref} />;
 *   }
 *
 *   const App = React.forwardRef((props, ref) => (
 *     <View {...props} forwardedRef={ref} />
 *   ));
 */
function useSharedRef(forwardedRef,
// ref callback
onRef) {
  var hostRef = React.useRef();
  function updater(ref) {
    onRef === null || onRef === void 0 ? void 0 : onRef(ref);
    // @ts-ignore
    hostRef.current = ref;
    if (typeof forwardedRef === 'function') {
      forwardedRef(ref);
    } else if ((0, _typeof2["default"])(forwardedRef) === 'object' && forwardedRef != null) {
      // @ts-ignore
      forwardedRef.current = ref;
    }
  }
  return {
    // Ref-based
    hostRef: hostRef,
    // Function-based
    ref: updater
  };
}