import React from 'react';
export declare enum PageContainerActionType {
    CANCEL = "cancel",
    OK = "ok",
    DEFAULT = "default"
}
export type PageContainerAction = {
    /**
     * @description 按钮类型
     */
    type?: PageContainerActionType | string;
    /**
     * @description 按钮 icon
     */
    icon?: React.ReactNode;
    /**
     * @description 按钮文本内容，由于jsapi限制，移动端暂只支持text传入string类型
     */
    text?: React.ReactNode | string;
    /**
     * @description 点击事件
     */
    onClick?: (close: () => void) => void;
    /**
     * @description 是否加载中
     * @default false
     */
    loading?: boolean;
    /**
     * @description 是否禁用
     * @default false
     */
    disabled?: boolean;
};
export interface PageContainerProps extends React.RefAttributes<HTMLDivElement>, React.HTMLAttributes<HTMLDivElement> {
    /**
     * @description 使用客户端能力渲染头部，限制条件：1. 只支持钉钉移动端 2. onBeforeClose 暂不支持
     */
    native?: boolean;
    /**
     * @description 是否全屏展示
     */
    fullScreen?: boolean;
    /**
     * @description 页面标题
     */
    title?: string;
    /**
     * @description 是否有后退按钮
     */
    hasBack?: boolean;
    /**
     * @description 可定义返回前的业务逻辑
     */
    onBeforeBack?: (next: () => void) => void;
    /**
     * @description 可定义关闭前的业务逻辑
     */
    onBeforeClose?: (next: () => void) => void;
    /**
     * @description 页面行动点
     */
    actions?: PageContainerAction[];
    /**
     * @description 强化主行动点（仅移动端）
     */
    strongMainAction?: boolean;
    /**
     * @description 是否撑满 H5 容器高度
     * @default true
     */
    full?: boolean;
    /**
     * @description 额外自定义内容（底部按钮区域）
     * @default
     */
    extra?: React.ReactNode;
    /**
     * @description 内容容器样式
     * @default
     */
    bodyStyle?: React.CSSProperties;
}
