/// <reference types="react" />
import type { AlignType } from 'rc-trigger/lib/interface';
export interface PopoverProps extends React.HTMLAttributes<HTMLDivElement> {
    /**
     * @description 是否可见
     * @default false
     */
    visible?: boolean;
    /**
     * @description 是否有蒙层
     * @default false
     */
    mask?: boolean;
    /**
     * @description 点击蒙层是否可以关闭
     * @default  true
     */
    maskClosable?: boolean;
    contentClassName?: string;
    /**
     * @description visible 变更时回调
     */
    onVisibleChange?: (visible: boolean) => void;
    /**
     * @description 渲染内容
     */
    overlay?: React.ReactNode;
    /**
     * @description 渲染到哪个节点
     * @default document.body
     */
    getPopupContainer?: (node: HTMLElement) => HTMLElement;
    /**
     * @description 打开方式
     * @default "click"
     */
    trigger?: 'hover' | 'click' | 'focus' | 'none';
    /**
     * @description 弹层 className
     */
    overlayClassName?: string;
    /**
     * @description 是否为深色 Popover
     */
    dark?: boolean;
    /**
     * @description 方向
     * @default "bottomRight"
     */
    placement?: 'left' | 'right' | 'top' | 'bottom' | 'topLeft' | 'topRight' | 'bottomLeft' | 'bottomRight';
    /**
     * @description 是否隐藏箭头
     * @default true
     */
    arrow?: boolean;
    /**
     * @description 设置弹窗的偏移量,可参考 https://github.com/yiminghe/dom-align
     */
    align?: AlignType;
}
