/**
 * Labelable
 *
 * 作用是让普通非表单组件拥有 label 可控的能力
 *
 * 1.
 * 如下所示，点击 label 的时候，X 组件内部的 handleFocus 会被触发
 * <label htmlFor="id" />
 *
 * <X id="id" />
 *
 * const X = props => {
 *  return <Labelable id={props.id} onFocus={handleFocus} />
 * }
 *
 * 2. Labelable 本身接受一个子元素，点击子元素的 div 也会触发 handleFocus
 *
 * const X = props => {
 *  return <Labelable onFocus={handleFocus}>
 *    <div />
 *  </Labelable>
 * }
 *
 * 3. autoFocus 属性会让组件渲染后就触发 handleFocus
 *
 * 4. 保留了 id, disabled, name, value, tabIndex, 使得表单提交的时候能正确获取值
 */
import * as React from 'react';
interface InputProps {
    id?: string;
    name?: string;
    disabled?: boolean;
    tabIndex?: number;
    value?: string;
}
export interface LabelInstance {
    focus(): void;
    blur(): void;
}
declare const _default: (React.MemoExoticComponent<React.ForwardRefExoticComponent<Pick<Omit<React.DetailedHTMLProps<React.InputHTMLAttributes<HTMLInputElement>, HTMLInputElement>, "ref"> & {
    ref?: React.Ref<LabelInstance> | undefined;
}, "key" | keyof React.InputHTMLAttributes<HTMLInputElement>> & React.RefAttributes<{}>>> | React.NamedExoticComponent<Omit<React.DetailedHTMLProps<React.InputHTMLAttributes<HTMLInputElement>, HTMLInputElement>, "ref"> & {
    ref?: React.Ref<LabelInstance> | undefined;
}>) & React.FC<Omit<React.DetailedHTMLProps<React.InputHTMLAttributes<HTMLInputElement>, HTMLInputElement>, "ref"> & {
    ref?: React.Ref<LabelInstance> | undefined;
}> & {
    getProps: (props: any) => InputProps;
};
export default _default;
