"use strict";

var _typeof = require("@babel/runtime/helpers/typeof");
Object.defineProperty(exports, "__esModule", {
  value: true
});
exports["default"] = void 0;
var React = _interopRequireWildcard(require("react"));
var _ErrorBoundary = require("../ErrorBoundary");
function _getRequireWildcardCache(e) { if ("function" != typeof WeakMap) return null; var r = new WeakMap(), t = new WeakMap(); return (_getRequireWildcardCache = function _getRequireWildcardCache(e) { return e ? t : r; })(e); }
function _interopRequireWildcard(e, r) { if (!r && e && e.__esModule) return e; if (null === e || "object" != _typeof(e) && "function" != typeof e) return { "default": e }; var t = _getRequireWildcardCache(r); if (t && t.has(e)) return t.get(e); var n = { __proto__: null }, a = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var u in e) if ("default" !== u && {}.hasOwnProperty.call(e, u)) { var i = a ? Object.getOwnPropertyDescriptor(e, u) : null; i && (i.get || i.set) ? Object.defineProperty(n, u, i) : n[u] = e[u]; } return n["default"] = e, t && t.set(e, n), n; }
/**
 * Labelable
 *
 * 作用是让普通非表单组件拥有 label 可控的能力
 *
 * 1.
 * 如下所示，点击 label 的时候，X 组件内部的 handleFocus 会被触发
 * <label htmlFor="id" />
 *
 * <X id="id" />
 *
 * const X = props => {
 *  return <Labelable id={props.id} onFocus={handleFocus} />
 * }
 *
 * 2. Labelable 本身接受一个子元素，点击子元素的 div 也会触发 handleFocus
 *
 * const X = props => {
 *  return <Labelable onFocus={handleFocus}>
 *    <div />
 *  </Labelable>
 * }
 *
 * 3. autoFocus 属性会让组件渲染后就触发 handleFocus
 *
 * 4. 保留了 id, disabled, name, value, tabIndex, 使得表单提交的时候能正确获取值
 */
var __assign = void 0 && (void 0).__assign || function () {
  __assign = Object.assign || function (t) {
    for (var s, i = 1, n = arguments.length; i < n; i++) {
      s = arguments[i];
      for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p)) t[p] = s[p];
    }
    return t;
  };
  return __assign.apply(this, arguments);
};
var __rest = void 0 && (void 0).__rest || function (s, e) {
  var t = {};
  for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p) && e.indexOf(p) < 0) t[p] = s[p];
  if (s != null && typeof Object.getOwnPropertySymbols === "function") for (var i = 0, p = Object.getOwnPropertySymbols(s); i < p.length; i++) {
    if (e.indexOf(p[i]) < 0 && Object.prototype.propertyIsEnumerable.call(s, p[i])) t[p[i]] = s[p[i]];
  }
  return t;
};
var hiddenStyle = {
  width: 0,
  height: 0,
  overflow: 'hidden',
  padding: 0,
  margin: 0,
  border: 0,
  display: 'block',
  visibility: 'hidden'
};
var Labelable = function Labelable(props) {
  var children = props.children,
    // @ts-ignore
    forwardRef = props.forwardRef,
    rest = __rest(props, ["children", "forwardRef"]);
  var inputRef = React.useRef(null);
  // 暂时只提供 focus 和 blur 两个方法
  React.useImperativeHandle(forwardRef, function () {
    return {
      focus: function focus() {
        var _a;
        (_a = inputRef.current) === null || _a === void 0 ? void 0 : _a.focus();
      },
      blur: function blur() {
        var _a;
        (_a = inputRef.current) === null || _a === void 0 ? void 0 : _a.blur();
      }
    };
  });
  return /*#__PURE__*/React.createElement(React.Fragment, null, /*#__PURE__*/React.createElement("label", null, /*#__PURE__*/React.createElement("input", __assign({}, rest, {
    ref: inputRef,
    // 必须有 readOnly , 不然会唤起真的键盘
    readOnly: true,
    style: hiddenStyle
  })), children));
};
Labelable.defaultProps = {
  type: 'text'
};
Labelable.getProps = function (props) {
  var keyMap = {
    id: true,
    name: true,
    tabIndex: true,
    value: true,
    disabled: true
  };
  return Object.keys(props).reduce(function (prev, item) {
    if (keyMap[item]) {
      // @ts-ignore
      prev[item] = props[item];
    }
    return prev;
  }, {});
};
var _default = exports["default"] = (0, _ErrorBoundary.withError)(Labelable, {
  forwardRef: true
});