import React from 'react';
import { BasePropsType } from '../_internal';
import './style/index';
import { NativeProps } from '../_internal/native-props';
import { SliderMarks } from './marks';
export declare const dtSliderPrefix: string;
export type SliderValue = number | [number, number];
export type ISliderProps = {
    /**
     * @description 最小值
     * @default 0
     */
    min?: number;
    /**
     * @description 最大值
     * @default 100
     */
    max?: number;
    /**
     * @description 当前值
     */
    value?: SliderValue;
    /**
     * @description 默认值
     * @default range ? [0,0] : 0
     */
    defaultValue?: SliderValue;
    /**
     * @description 步长
     * @default 1
     */
    step?: number;
    /**
     * @description 是否支持双滑块
     * @default false
     */
    range?: boolean;
    /**
     * @description 显示刻度标记或者自定义刻度标记
     * @default false
     */
    marks?: SliderMarks | boolean;
    /**
     * @description 是否显示刻度
     * @default false
     */
    ticks?: boolean;
    /**
     * @description 显示终点标记或者自定义刻度标记
     * @default false
     */
    endMarks?: boolean;
    /**
     * @description 是否禁用
     * @description false
     */
    disabled?: boolean;
    /**
     * @description 拖拽滑块时触发，并将当前拖拽的值作为参数传入
     */
    onChange?: (value: SliderValue) => void;
    /**
     * @description 拖拽滑块结束时触发，并把当前值作为参数传入
     */
    onAfterChange?: (value: SliderValue) => void;
} & BasePropsType & NativeProps<'--active-text-color' | '--width'>;
declare const Slider: React.FC<ISliderProps>;
export default Slider;
