"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");
Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.dtSliderPrefix = exports["default"] = void 0;
var _react = _interopRequireDefault(require("react"));
require("./style/index");
var _index2 = require("../style/index");
var _classnames = _interopRequireDefault(require("classnames"));
var _nativeProps = require("../_internal/native-props");
var _withDefaultProps = require("../_internal/with-default-props");
var _usePropsValue = require("../_internal/use-props-value");
var _nearest = require("../_internal/nearest");
var _thumb = require("./thumb");
var _marks = require("./marks");
var _ticks = require("./ticks");
var __read = void 0 && (void 0).__read || function (o, n) {
  var m = typeof Symbol === "function" && o[Symbol.iterator];
  if (!m) return o;
  var i = m.call(o),
    r,
    ar = [],
    e;
  try {
    while ((n === void 0 || n-- > 0) && !(r = i.next()).done) ar.push(r.value);
  } catch (error) {
    e = {
      error: error
    };
  } finally {
    try {
      if (r && !r.done && (m = i["return"])) m.call(i);
    } finally {
      if (e) throw e.error;
    }
  }
  return ar;
};
var __spreadArray = void 0 && (void 0).__spreadArray || function (to, from, pack) {
  if (pack || arguments.length === 2) for (var i = 0, l = from.length, ar; i < l; i++) {
    if (ar || !(i in from)) {
      if (!ar) ar = Array.prototype.slice.call(from, 0, i);
      ar[i] = from[i];
    }
  }
  return to.concat(ar || Array.prototype.slice.call(from));
};
var dtSliderPrefix = exports.dtSliderPrefix = "".concat(_index2.dtMobilePrefix, "-slider");
var defaultProps = {
  min: 0,
  max: 100,
  step: 1,
  range: false,
  tick: false,
  disabled: false,
  endMarks: false
};
var sortValue = function sortValue(val) {
  return val.sort(function (a, b) {
    return a - b;
  });
};
var Slider = /*#__PURE__*/_react["default"].memo(function (p) {
  var _a;
  var _b;
  var props = (0, _withDefaultProps.mergeProps)(defaultProps, p);
  var className = props.className,
    min = props.min,
    max = props.max,
    disabled = props.disabled,
    range = props.range,
    marks = props.marks,
    endMarks = props.endMarks,
    ticks = props.ticks,
    step = props.step,
    onChange = props.onChange;
  var wrapCls = (0, _classnames["default"])(dtSliderPrefix, className, (_a = {}, _a["".concat(dtSliderPrefix, "-disabled")] = disabled, _a));
  //----- 工具方法
  // 转化当前值为范围值
  var convertValue = function convertValue(value) {
    // 捕捉意外的错误
    if (props.range && !Array.isArray(value)) {
      return [props.min, value];
    } else {
      return props.range ? value : [props.min, value];
    }
  };
  var reverseValue = _react["default"].useCallback(function (value) {
    return range ? value : value[1];
  }, [range]);
  var onAfterChange = _react["default"].useCallback(function (value) {
    var _a;
    return (_a = props.onAfterChange) === null || _a === void 0 ? void 0 : _a.call(props, reverseValue(value));
  }, [props.onAfterChange]);
  var _c = __read((0, _usePropsValue.usePropsValue)({
      value: props.value,
      defaultValue: (_b = props.defaultValue) !== null && _b !== void 0 ? _b : props.range ? [min, min] : min,
      onChange: onChange
    }), 2),
    rawValue = _c[0],
    setRawValue = _c[1];
  // 计算当前的范围值，并设置为百分比
  var sliderValue = sortValue(convertValue(rawValue));
  function setSliderValue(value) {
    var next = sortValue(value);
    var current = sliderValue;
    if (next[0] === current[0] && next[1] === current[1]) return;
    setRawValue(reverseValue(next));
  }
  var fillEnd = "".concat(100 * (sliderValue[1] - sliderValue[0]) / (max - min), "%");
  var fillStart = "".concat(100 * (sliderValue[0] - min) / (max - min), "%");
  var trackRef = _react["default"].useRef(null);
  var dragLockRef = _react["default"].useRef(0);
  var valueBeforeDragRef = _react["default"].useRef();
  // 计算要显示的点
  var pointList = _react["default"].useMemo(function () {
    if (marks && typeof marks !== 'boolean' && ticks) {
      return Object.keys(marks).map(parseFloat).sort(function (a, b) {
        return a - b;
      });
    } else {
      var points = [];
      for (var i = min; i <= max; i += step) {
        points.push(i);
      }
      return points;
    }
  }, [marks, ticks, step, min, max]);
  function getValueByPosition(position) {
    var newPosition = position < min ? min : position > max ? max : position;
    var value = min;
    // 显示了刻度点，就只能移动到点上
    if (pointList.length) {
      value = (0, _nearest.nearest)(pointList, newPosition);
    } else {
      var lengthPerStep = 100 / ((max - min) / step);
      var steps = Math.round(newPosition / lengthPerStep);
      value = steps * lengthPerStep * (max - min) * 0.01 + min;
    }
    return value;
  }
  var onSliderClick = function onSliderClick(event) {
    if (dragLockRef.current > 0) return;
    event.stopPropagation();
    if (disabled) return;
    var track = trackRef.current;
    if (!track) return;
    var sliderOffsetLeft = track.getBoundingClientRect().left;
    var position = (event.clientX - sliderOffsetLeft) / Math.ceil(track.offsetWidth) * (max - min) + min;
    var targetValue = getValueByPosition(position);
    var nextSliderValue;
    if (props.range) {
      // 移动的滑块采用就近原则
      if (Math.abs(targetValue - sliderValue[0]) > Math.abs(targetValue - sliderValue[1])) {
        nextSliderValue = [sliderValue[0], targetValue];
      } else {
        nextSliderValue = [targetValue, sliderValue[1]];
      }
    } else {
      nextSliderValue = [props.min, targetValue];
    }
    setSliderValue(nextSliderValue);
    onAfterChange(nextSliderValue);
  };
  var renderThumb = function renderThumb(index) {
    return /*#__PURE__*/_react["default"].createElement(_thumb.Thumb, {
      key: index,
      value: sliderValue[index],
      min: min,
      max: max,
      disabled: disabled,
      trackRef: trackRef,
      onDrag: function onDrag(position, first, last) {
        // first 滑动的第一次变化
        // last 滑动的最后一次变化
        if (first) {
          dragLockRef.current += 1;
          valueBeforeDragRef.current = sliderValue;
        }
        var val = getValueByPosition(position);
        var valueBeforeDrag = valueBeforeDragRef.current;
        if (!valueBeforeDrag) return;
        var next = __spreadArray([], __read(valueBeforeDrag), false);
        next[index] = val;
        setSliderValue(next);
        if (last) {
          onAfterChange(next);
          window.setTimeout(function () {
            dragLockRef.current -= 1;
          }, 100);
        }
      }
    });
  };
  return (0, _nativeProps.withNativeProps)(props, /*#__PURE__*/_react["default"].createElement("div", {
    className: wrapCls
  }, /*#__PURE__*/_react["default"].createElement("div", {
    className: "".concat(dtSliderPrefix, "-container"),
    onClick: onSliderClick
  }, /*#__PURE__*/_react["default"].createElement("div", {
    className: "".concat(dtSliderPrefix, "-line"),
    onClick: onSliderClick,
    ref: trackRef
  }, /*#__PURE__*/_react["default"].createElement("div", {
    className: "".concat(dtSliderPrefix, "-line-fill"),
    style: {
      width: fillEnd,
      left: fillStart
    }
  }), props.ticks && (/*#__PURE__*/_react["default"].createElement(_ticks.Ticks, {
    points: pointList,
    min: min,
    max: max,
    lowerBound: sliderValue[0],
    upperBound: sliderValue[1]
  })), props.range && renderThumb(0), renderThumb(1)), endMarks && (/*#__PURE__*/_react["default"].createElement("div", {
    className: "".concat(dtSliderPrefix, "-end-marks")
  }, max))), marks && (/*#__PURE__*/_react["default"].createElement(_marks.Marks, {
    step: step,
    min: min,
    max: max,
    marks: marks,
    lowerBound: sliderValue[0],
    upperBound: sliderValue[1]
  }))));
});
Slider.displayName = 'Slider';
var _default = exports["default"] = Slider;