/// <reference types="react" />
import type { NativeProps } from './../_internal/native-props';
export declare enum TagColorEnum {
    Default = "default",
    Primary = "primary",
    Success = "success",
    Warning = "warning",
    Danger = "danger"
}
export interface TagProps extends NativeProps {
    /**
     * @description 组件类型，主要描述颜色
     * @deprecated
     * @default "normal"
     */
    type?: 'blue' | 'orange' | 'red' | 'green' | 'water' | 'normal';
    /**
     * @description 组件大小
     * @default "small"
     */
    size?: 'medium' | 'small';
    /**
     * @description 是否可关闭 （非 disabled small 状态）
     * @default false
     */
    closable?: boolean;
    /**
     * @description 点关闭时的回调函数
     */
    onClose?: () => void;
    /**
     * @description 标签左侧的icon
     */
    icon?: string | React.ReactNode | (() => React.ReactNode);
    /**
     * @description 点击标签触发的事件，当closable为false时，可以用该方法监听标签的点击行为
     * @param e
     * @returns
     */
    onClick?: (e: React.MouseEvent<HTMLSpanElement, MouseEvent>) => void;
    /**
     * @description 采用边框模式，还是实心模式
     * @default size为'small'时，默认为outline，size为'medium'时，默认为solid
     */
    fill?: 'solid' | 'outline';
    /**
     * @description 与type类似，但可以传入颜色进行自定义，比如 '#fff'(version > 2.2.0)
     */
    color?: TagColorEnum | string;
}
export interface CheckableTagProps extends NativeProps, TagProps {
    /**
     * @description 设置标签的选中状态
     */
    checked?: boolean;
    /**
     * 点击标签时触发的回调
     * @param checked
     * @returns
     */
    onChange?: (checked: boolean) => void;
}
